@@ -338,7 +338,7 @@ void KGetMetalink::Metaurl::save(QDomElement &e) const
 
 bool KGetMetalink::Metaurl::isValid()
 {
-    return url.isValid() && !type.isEmpty();
+    return url.isValid() && url.hasHost() && !url.protocol().isEmpty() && !type.isEmpty();
 }
 
 void KGetMetalink::Metaurl::clear()
@@ -393,17 +393,7 @@ void KGetMetalink::Url::save(QDomElement &e) const
 
 bool KGetMetalink::Url::isValid()
 {
-    bool valid = url.isValid();
-    if (url.fileName().endsWith(QLatin1String(".torrent")))
-    {
-        valid = false;
-    }
-    else if (url.fileName().endsWith(QLatin1String(".metalink")) || url.fileName().endsWith(QLatin1String(".meta4")))
-    {
-        valid = false;
-    }
-
-    return valid;
+    return url.isValid() && url.hasHost() && !url.protocol().isEmpty();
 }
 
 void KGetMetalink::Url::clear()
@@ -1311,9 +1301,9 @@ bool KGetMetalink::HandleMetalink::save(const KUrl &destination, KGetMetalink::M
 
     QDomDocument doc;
     QString fileName = destination.fileName();
-    if (fileName.endsWith("meta4")) {
+    if (fileName.endsWith(QLatin1String("meta4"))) {
         doc = metalink->save();
-    } else if (fileName.endsWith("metalink")) {
+    } else if (fileName.endsWith(QLatin1String("metalink"))) {
         Metalink_v3 metalink_v3;
         metalink_v3.setMetalink(*metalink);
         doc = metalink_v3.save();
