@@ -16,6 +16,8 @@
   * *************************************************************************
   */
 
+#include "jabberbasecontact.h"
+
 #include <kdebug.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -31,8 +33,6 @@
 #include <kopetecontactlist.h>
 #include <kopeteavatarmanager.h>
 
-#include "jabberbasecontact.h"
-
 #include "xmpp_tasks.h"
 
 #include "jabberprotocol.h"
@@ -206,6 +206,12 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 			kDebug ( JABBER_DEBUG_GLOBAL ) << "Adding " << contactId() << " to group " << group->displayName ();
 			metaContact()->addToGroup ( group );
 		}
+
+		//Set nick name from roster
+		if ( ! item.name().isEmpty() )
+		{
+			setProperty ( protocol()->propNickName, item.name() );
+		}
 	}
 
 	/*
@@ -335,7 +341,7 @@ QString JabberBaseContact::fullAddress ()
 
 	if ( jid.resource().isEmpty () )
 	{
-		jid.withResource ( account()->resourcePool()->bestResource ( jid ).name () );
+		jid = jid.withResource ( account()->resourcePool()->bestResource ( jid ).name () );
 	}
 
 	return jid.full ();
@@ -354,7 +360,7 @@ XMPP::Jid JabberBaseContact::bestAddress ()
 
 	// construct address out of user@host and current best resource
 	XMPP::Jid jid = mRosterItem.jid ();
-	jid.withResource ( account()->resourcePool()->bestResource( mRosterItem.jid() ).name () );
+	jid = jid.withResource ( account()->resourcePool()->bestResource( mRosterItem.jid() ).name () );
 
 	return jid;
 
@@ -414,7 +420,11 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	*/
 	if(inherits ( "JabberContact" ))
 	{
-		if ( !vCard.nickName().isEmpty () )
+		if ( !mRosterItem.name().isEmpty() )
+		{
+			setProperty ( protocol()->propNickName, mRosterItem.name() );
+		}
+		else if ( !vCard.nickName().isEmpty () )
 		{
 			setProperty ( protocol()->propNickName, vCard.nickName () );
 		}
