@@ -17,6 +17,7 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "jabbereditaccountwidget.h"
 #include <kdebug.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
@@ -42,7 +43,6 @@
 #include "kopetepasswordwidget.h"
 
 #include "jabberclient.h"
-#include "jabbereditaccountwidget.h"
 #include "jabberregisteraccount.h"
 #include "dlgjabberchangepassword.h"
 #include "privacydlg.h"
@@ -67,6 +67,8 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 	connect (btnChangePassword, SIGNAL ( clicked() ), this, SLOT ( slotChangePasswordClicked () ));
 	
 	connect (privacyListsButton, SIGNAL ( clicked() ), this, SLOT ( slotPrivacyListsClicked() ) );
+
+	connect (cbAdjustPriority, SIGNAL (toggled (bool)), this, SLOT ( awayPriorityToggled (bool)));
 	
 #ifdef JINGLE_SUPPORT
 	checkAudioDevices();
@@ -82,6 +84,18 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 	}
 #endif
 
+#ifndef GOOGLETALK_SUPPORT
+	//Remove Google Talk tab
+	for ( int i=0; i<tabWidget10->count(); ++i )
+	{
+		if ( tabWidget10->tabText(i) == "&Google Talk" )
+		{
+			tabWidget10->removeTab(i);
+			break;
+		}
+	}
+#endif
+
 	if (account())
 	{
 		// we are working with an existing account
@@ -185,6 +199,17 @@ void JabberEditAccountWidget::reopen ()
 		mServer->setText(mID->text().section('@', 1));
 	}
 
+	if ( account()->configGroup()->hasKey("AwayPriority") )
+	{
+		cbAdjustPriority->setChecked(true);
+		mAwayPriority->setValue( account()->configGroup()->readEntry("AwayPriority",0));
+	}
+	else
+	{
+		cbAdjustPriority->setChecked(false);
+		mAwayPriority->setEnabled(false);
+	}
+
 	cbAllowPlainTextPassword->setChecked (account()->configGroup()->readEntry("AllowPlainTextPassword", true));
 
 	KConfigGroup config = KGlobal::config()->group("Jabber");
@@ -226,6 +251,14 @@ void JabberEditAccountWidget::reopen ()
 	cbSendGoneEvent->setChecked( account()->configGroup()->readEntry("SendGoneEvent", true) );
 
 	cbHideSystemInfo->setChecked( account()->configGroup()->readEntry("HideSystemInfo", false) );
+
+	mergeMessages->setChecked(account()->mergeMessages());
+	oldEncrypted->setChecked(account()->oldEncrypted());
+
+#ifdef GOOGLETALK_SUPPORT
+	GoogleTalk->setChecked(account()->enabledGoogleTalk());
+#endif
+
 }
 
 Kopete::Account *JabberEditAccountWidget::apply ()
@@ -268,6 +301,16 @@ void JabberEditAccountWidget::writeConfig ()
 	account()->configGroup()->writeEntry("Server", mServer->text().trimmed ());
 	account()->configGroup()->writeEntry("Resource", mResource->text ());
 	account()->configGroup()->writeEntry("Priority", QString::number (mPriority->value ()));
+
+	if ( cbAdjustPriority->isChecked() )
+	{
+		account()->configGroup()->writeEntry("AwayPriority", QString::number( mAwayPriority->value ()));
+	}
+	else
+	{
+		account()->configGroup()->deleteEntry("AwayPriority");
+	}
+
 	account()->configGroup()->writeEntry("Port", QString::number (mPort->value ()));
 
 #ifdef JINGLE_SUPPORT
@@ -295,6 +338,14 @@ void JabberEditAccountWidget::writeConfig ()
 	account()->configGroup()->writeEntry("SendGoneEvent", cbSendGoneEvent->isChecked());
 	
 	account()->configGroup()->writeEntry("HideSystemInfo", cbHideSystemInfo->isChecked());
+
+	account()->setMergeMessages(mergeMessages->isChecked());
+	account()->setOldEncrypted(oldEncrypted->isChecked());
+
+#ifdef GOOGLETALK_SUPPORT
+	account()->enableGoogleTalk(GoogleTalk->isChecked());
+#endif
+
 }
 
 bool JabberEditAccountWidget::validateData ()
@@ -309,6 +360,14 @@ bool JabberEditAccountWidget::validateData ()
 		return false;
 	}
 
+#ifdef GOOGLETALK_SUPPORT
+	if ( GoogleTalk->isChecked() && mServer->text().trimmed() != "talk.google.com" )
+	{
+		KMessageBox::sorry(this, i18n("Google Talk libjingle support is only for GTalk/Gmail account, which connect to server talk.google.com."), i18n("Invalid Google Talk"));
+		return false;
+	}
+#endif
+
 	return true;
 }
 
@@ -337,6 +396,11 @@ void JabberEditAccountWidget::updateServerField ()
 
 }
 
+void JabberEditAccountWidget::awayPriorityToggled(bool enabled)
+{
+	mAwayPriority->setEnabled(enabled);
+}
+
 void JabberEditAccountWidget::deleteClicked ()
 {
 
