@@ -49,9 +49,11 @@ bool PictureNotifierTask::take( Transfer* transfer )
 	{	
 		case Yahoo::ServicePictureStatus:
 			parsePictureStatus( t );
+			parsePicture( t );
 		break;
 		case Yahoo::ServicePictureChecksum:
 			parsePictureChecksum( t );
+			parsePicture( t );
 		break;
 		case Yahoo::ServicePicture:
 			parsePicture( t );
@@ -100,7 +102,7 @@ void PictureNotifierTask::parsePictureStatus( YMSGTransfer *t )
 void PictureNotifierTask::parsePictureChecksum( YMSGTransfer *t )
 {
 	kDebug(YAHOO_RAW_DEBUG) ;
-
+	parsePicture( t );
 	QString	nick;		/* key = 4 */
 	int checksum;		/* key = 192  */
 
@@ -116,7 +118,7 @@ void PictureNotifierTask::parsePicture( YMSGTransfer *t )
 	kDebug(YAHOO_RAW_DEBUG) ;
 
 	QString	nick;		/* key = 4 */
-	int type;		/* key = 13: 1 = request, 2 = notification */
+	int type;		/* key = 13: 1 = request, 2 = notification, 0 = Just changed */
 	QString url;		/* key = 20 */
 	int checksum;		/* key = 192  */
 
@@ -127,6 +129,8 @@ void PictureNotifierTask::parsePicture( YMSGTransfer *t )
 	
 	if( type == 1 )
 		emit pictureRequest( nick );
+	else if( type == 0 )
+		emit pictureInfoNotify( nick, KUrl( url ), checksum );
 	else if( type == 2 )
 		emit pictureInfoNotify( nick, KUrl( url ), checksum );
 }
