@@ -20,13 +20,11 @@
 #include "ymsgtransfer.h"
 #include "yahootypes.h"
 #include "client.h"
+#include "webcamimgformat.h"
 
 #include <QBuffer>
-#include <QFile>
 #include <QTimer>
 #include <QPixmap>
-#include <ktemporaryfile.h>
-#include <kprocess.h>
 #include <k3streamsocket.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -80,8 +78,10 @@ void WebcamTask::requestWebcam( const QString &who )
 	YMSGTransfer *t = new YMSGTransfer(Yahoo::ServiceWebcam);
 	t->setId( client()->sessionID() );
 	t->setParam( 1, client()->userId().toLocal8Bit());
-	t->setParam( 5, who.toLocal8Bit() );
-	keyPending = who;
+
+	if (!who.isEmpty())
+		t->setParam( 5, who.toLocal8Bit() );
+	keysPending.append(who);
 
 	send( t );
 }
@@ -91,7 +91,9 @@ void WebcamTask::parseWebcamInformation( YMSGTransfer *t )
 	kDebug(YAHOO_RAW_DEBUG) ;
 
 	YahooWebcamInformation info;
-	info.sender = keyPending;
+	if (!keysPending.isEmpty())
+		info.sender = keysPending.takeFirst();
+
 	info.server = t->firstParam( 102 );
 	info.key = t->firstParam( 61 );
 	info.status = InitialStatus;
@@ -99,7 +101,7 @@ void WebcamTask::parseWebcamInformation( YMSGTransfer *t )
 	info.buffer = 0L;
 	info.headerRead = false;
 	if(info.sender.isEmpty()){
-		info.server = t->firstParam( 4 );
+		info.sender = t->firstParam( 4 );
 	}
 	if( info.sender == client()->userId() )
 	{
@@ -462,36 +464,16 @@ void WebcamTask::parseData( QByteArray &data, KStreamSocket *socket )
 			{
 			QPixmap webcamImage;
 			//webcamImage.loadFromData( info->buffer->buffer() );
-	
-			KTemporaryFile jpcTmpImageFile;
-			jpcTmpImageFile.setAutoRemove(false);
-			jpcTmpImageFile.open();
-			KTemporaryFile bmpTmpImageFile;
-			bmpTmpImageFile.setAutoRemove(false);
-			bmpTmpImageFile.open();
-
-			jpcTmpImageFile.write((info->buffer->buffer()).data(), info->buffer->size());
-			jpcTmpImageFile.close();
-			
-			KProcess p;
-			p << "jasper";
-			p << "--input" << jpcTmpImageFile.fileName() << "--output" << bmpTmpImageFile.fileName() << "--output-format" << "bmp";
-			
-			int ec = p.execute();
-			if( ec != 0 )
+			if (WebcamImgFormat::instance())
 			{
-				kDebug(YAHOO_RAW_DEBUG) << " jasper exited with status " << ec << " " << info->sender;
-			}
-			else
-			{
-				webcamImage.load( bmpTmpImageFile.fileName() );
-				/******* UPTO THIS POINT ******/
-				emit webcamImageReceived( info->sender, webcamImage );
-			}
-			QFile::remove(jpcTmpImageFile.fileName());
-			QFile::remove(bmpTmpImageFile.fileName());
-	
-			kDebug(YAHOO_RAW_DEBUG) << "Image Received. Size: " << webcamImage.size();
+				if (WebcamImgFormat::instance()->fromYahoo(webcamImage, info->buffer->buffer().constData(), info->buffer->buffer().size()))
+				{
+					kDebug(YAHOO_RAW_DEBUG) << "Image Received and converted. Size: " << webcamImage.size();
+					emit webcamImageReceived( info->sender, webcamImage );
+				} else
+					kDebug(YAHOO_RAW_DEBUG) << "Failed to convert incoming Yahoo webcam image";
+			} else
+				kDebug(YAHOO_RAW_DEBUG) << "Failed to initialize WebcamImgFormat helper";
 			}
 		break;
 		default:
@@ -551,7 +533,7 @@ void WebcamTask::registerWebcam()
 	YMSGTransfer *t = new YMSGTransfer(Yahoo::ServiceWebcam);
 	t->setId( client()->sessionID() );
 	t->setParam( 1, client()->userId().toLocal8Bit());
-	keyPending  = client()->userId();
+	keysPending.append(client()->userId());
 
 	send( t );
 }
